@@ -1,7 +1,8 @@
 package Catalyst::Helper::View::Mason;
 
 use strict;
-use warnings;
+
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -9,7 +10,7 @@ Catalyst::Helper::View::Mason - Helper for Mason Views
 
 =head1 SYNOPSIS
 
-    script/create.pl view Mason Mason
+    bin/create view Mason Mason
 
 =head1 DESCRIPTION
 
@@ -22,43 +23,18 @@ Helper for Mason Views.
 =cut
 
 sub mk_compclass {
-    my ($self, $helper) = @_;
-    my $file = $helper->{file};
-    $helper->render_file('compclass', $file);
-}
-
-=head1 SEE ALSO
-
-L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
-L<Catalyst::Response>, L<Catalyst::Helper>
-
-=head1 AUTHOR
-
-Andres Kievsky
-Sebastian Riedel, C<sri@oook.de>
-
-=head1 LICENSE
-
-This library is free software . You can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut
-
-1;
-
-__DATA__
-
-__compclass__
-package [% class %];
+    my ( $self, $helper ) = @_;
+    my $file  = $helper->{file};
+    my $class = $helper->{class};
+    $helper->mk_file( $file, <<"EOF");
+package $class;
 
 use strict;
 use base 'Catalyst::View::Mason';
 
-__PACKAGE__->config(use_match => 0);
-
 =head1 NAME
 
-[% class %] - Mason View Component
+$class - Mason View Component
 
 =head1 SYNOPSIS
 
@@ -80,3 +56,27 @@ the same terms as perl itself.
 =cut
 
 1;
+EOF
+}
+
+=head1 SEE ALSO
+
+L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
+L<Catalyst::Response>, L<Catalyst::Helper>
+
+=head1 AUTHOR
+
+Andres Kievsky, C<ank@cpan.org>
+
+based on the TT View Helper from:
+
+Sebastian Riedel, C<sri@oook.de>
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut
+
+1;
